@@ -7,7 +7,7 @@
  *  within the code that implements the API.
  */
 
-// Copyright (C) 2014-2020 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2023 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef DDCUTIL_TYPES_H_
@@ -18,10 +18,10 @@ extern "C"
 {
 #endif
 
-/** \cond */
+/** @cond */
 #include <stdbool.h>
 #include <stdint.h>                // for uint8_t, unit16_t
-/** \endcond */
+/** @endcond */
 
 
 //
@@ -34,19 +34,19 @@ extern "C"
  *  Most public **ddcutil** functions return a status code.
  *  These status codes have 3 sources:
  *  - Linux
- *  - ADL (AMD Display Library)
+ *  - ADL (AMD Display Library) (no longer used)
  *  - **ddcutil** itself
  *
  *  These multiple status code sources are consolidated by "modulating"
  *  the raw values into non-overlapping ranges.
  *  - Linux errno values are returned as negative numbers (e.g. -EIO)
  *  - ADL values are modulated by 2000 (i.e., 2000 subtracted from negative ADL status codes,
- *         or added to positive ADL status codes)
+ *         or added to positive ADL status codes) (no longer used)
  *  - ddcutil errors are always in the -3000 range
  *
  *  In summary:
  *  - 0 always indicates a normal successful status
- *  - Positive values (possible with ADL) represent qualified success of some sort
+ *  - Positive values (possible with ADL) represent qualified success of some sort (no longer used)
  *  - Negative values indicate an error condition.
  */
 typedef int DDCA_Status;
@@ -67,8 +67,7 @@ typedef struct {
 //! Build option flags, as returned by #ddca_build_options()
 //! The enum values are defined as 1,2,4 etc so that they can be or'd.
 typedef enum {
-   /** @brief ddcutil was built with support for AMD Display Library connected monitors */
-   DDCA_BUILT_WITH_ADL     = 0x01,
+   DDCA_BUILT_WITH_NONE    = 0x00,
    /** @brief ddcutil was built with support for USB connected monitors */
    DDCA_BUILT_WITH_USB     = 0x02,
   /** @brief ddcutil was built with support for failure simulation */
@@ -92,21 +91,16 @@ typedef struct ddca_error_detail {
 
 
 //
-// I2C Protocol Control
+// Initialization
 //
 
-//! I2C timeout types
-typedef enum{
-   DDCA_TIMEOUT_STANDARD,      /**< Normal retry interval */
-   DDCA_TIMEOUT_TABLE_RETRY    /**< Special timeout for Table reads and writes */
-} DDCA_Timeout_Type;
+typedef enum {
+   DDCA_INIT_OPTIONS_NONE                 = 0,
+   DDCA_INIT_OPTIONS_DISABLE_CONFIG_FILE  = 1,
+   DDCA_INIT_OPTIONS_CLIENT_OPENED_SYSLOG = 2
+} DDCA_Init_Options;
+
 
-//! I2C retry limit types
-typedef enum{
-   DDCA_WRITE_ONLY_TRIES,     /**< Maximum write-only operation tries */
-   DDCA_WRITE_READ_TRIES,     /**< Maximum read-write operation tries */
-   DDCA_MULTI_PART_TRIES      /**< Maximum multi-part operation tries */
-} DDCA_Retry_Type;
 
 
 //
@@ -130,34 +124,22 @@ typedef enum {
 // Tracing
 //
 
-//! Trace Control
+
+
+//! ddcutil message severity
 //!
-//! Used as bitflags to specify multiple trace types
+//! will be mapped to syslog() severity
+//! gaps in value allow for further refinement
 typedef enum {
- DDCA_TRC_BASE  = 0x0080,       /**< base functions          */
- DDCA_TRC_I2C   = 0x0040,       /**< I2C layer               */
- DDCA_TRC_ADL   = 0x0020,       /**< ADL layer               */
- DDCA_TRC_DDC   = 0x0010,       /**< DDC layer               */
- DDCA_TRC_USB   = 0x0008,       /**< USB connected display functions */
- DDCA_TRC_TOP   = 0x0004,       /**< ddcutil mainline        */
- DDCA_TRC_ENV   = 0x0002,       /**< environment command     */
- DDCA_TRC_API   = 0x0001,       /**< top level API functions */
- DDCA_TRC_UDF   = 0x0100,       /**< user-defined, aka dynamic, features */
- DDCA_TRC_VCP   = 0x0200,       /**< VCP layer, feature definitions */
- DDCA_TRC_DDCIO = 0x0400,       /**< DDC IO functions */
- DDCA_TRC_SLEEP = 0x0800,       /**< low level sleeps */
- DDCA_TRC_RETRY = 0x1000,       /**< successful retries, subset of DDCA_TRC_SLEEP */
-
- DDCA_TRC_NONE = 0x0000,        /**< all tracing disabled    */
- DDCA_TRC_ALL  = 0xffff         /**< all tracing enabled     */
-} DDCA_Trace_Group;
-
-
-typedef enum {
-   DDCA_TRCOPT_TIMESTAMP = 0x01,
-   DDCA_TRCOPT_THREAD_ID = 0x02,
-   DDCA_TRCOPT_WALLTIME  = 0x04
-} DDCA_Trace_Options;
+   DDCA_SYSLOG_NOT_SET  =  -1,
+   DDCA_SYSLOG_NEVER    =   0,
+   DDCA_SYSLOG_ERROR    =   3,
+   DDCA_SYSLOG_WARNING  =   6,
+   DDCA_SYSLOG_NOTICE   =   9,
+   DDCA_SYSLOG_INFO     =  12,
+   DDCA_SYSLOG_VERBOSE  =  15,
+   DDCA_SYSLOG_DEBUG    =  18,
+} DDCA_Syslog_Level;
 
 
 //
@@ -195,7 +177,7 @@ typedef enum {
 //  Display Specification
 //
 
-/** \defgroup api_display_spec API Display Specification */
+/** @defgroup api_display_spec API Display Specification */
 
 /** Opaque display identifier
  *
@@ -205,12 +187,12 @@ typedef enum {
  * It can take several forms:
  * - the display number assigned by **dccutil**
  * - an I2C bus number
- * - an ADL (adapter index, display index) pair
+ * - an ADL (adapter index, display index) pair (deprecated)
  * - a  USB (bus number, device number) pair or USB device number
  * - an EDID
  * - manufacturer, model, and serial number strings
  *
- * \ingroup api_display_spec
+ * @ingroup api_display_spec
  * */
 typedef void * DDCA_Display_Identifier;
 
@@ -218,8 +200,8 @@ typedef void * DDCA_Display_Identifier;
  *
  * A #DDCA_Display_Ref describes a monitor.  It contains 3 kinds of information:
  * - Assigned ddcutil display number
- * - The operating system path to the monitor, which is an I2C bus number, an
- *   ADL identifier, or a USB device number.
+ * - The operating system path to the monitor, which is an I2C bus number or
+ *   a USB device number.
  * - Accumulated information about the monitor, such as the EDID or capabilities string.
  *
  * @remark
@@ -230,7 +212,7 @@ typedef void * DDCA_Display_Identifier;
  * - From the DDCA_Display_List returned by #ddca_get_display_info_list2()
  * - Searching based on #DDCA_Display_Identifier using #ddca_get_display_ref()
  *
- * \ingroup api_display_spec
+ * @ingroup api_display_spec
  */
 typedef void * DDCA_Display_Ref;
 
@@ -244,25 +226,14 @@ typedef void * DDCA_Display_Ref;
  * For I2C and USB connected displays, an operating system open is performed by
  * # ddca_open_display2().  #DDCA_Display_Handle then contains the file handle
  * returned by the operating system.
- * For ADL displays, no actual operating system open is performed when creating
- * a DDCA_Display_Handle.  The adapter number.device number pair are simply copied
- * from the #DDCA_Display_Ref.
  *
- * \ingroup api_display_spec
+ * @ingroup api_display_spec
  */
 typedef void * DDCA_Display_Handle;
 
 ///@}
 
 
-/** ADL adapter number/display number pair, which identifies a display */
-typedef struct {
-   int iAdapterIndex;  /**< adapter number */
-   int iDisplayIndex;  /**< display number */
-} DDCA_Adlno;
-// uses -1,-1 for unset
-
-
 //
 // VCP Feature Information
 //
@@ -324,7 +295,6 @@ typedef enum {
 /** Indicates how MCCS communication is performed */
 typedef enum {
    DDCA_IO_I2C,     /**< Use DDC to communicate with a /dev/i2c-n device */
-   DDCA_IO_ADL,     /**< Use ADL API */
    DDCA_IO_USB      /**< Use USB reports for a USB connected monitor */
 } DDCA_IO_Mode;
 
@@ -334,7 +304,6 @@ typedef struct {
    DDCA_IO_Mode io_mode;        ///< physical access mode
    union {
       int        i2c_busno;     ///< I2C bus number
-      DDCA_Adlno adlno;         ///< ADL iAdapterIndex/iDisplayIndex pair
       int        hiddev_devno;  ///* USB hiddev device  number
    } path;
 } DDCA_IO_Path;
@@ -464,7 +433,7 @@ struct {
    DDCA_MCCS_Version_Spec                vcp_version;    /**< MCCS version    */
    DDCA_Feature_Flags                    feature_flags;  /**< feature type description */
    DDCA_Feature_Value_Entry *            sl_values;      /**< valid when DDCA_SIMPLE_NC set */
-   DDCA_Feature_Value_Entry *            latest_sl_values;
+   DDCA_Feature_Value_Entry *            latest_sl_values;  /** no longer used */
    char *                                feature_name;   /**< feature name */
    char *                                feature_desc;   /**< feature description */
    // possibly add pointers to formatting functions
@@ -553,6 +522,7 @@ typedef struct {
 #define VALREC_CUR_VAL(valrec) ( valrec->val.c_nc.sh << 8 | valrec->val.c_nc.sl )
 #define VALREC_MAX_VAL(valrec) ( valrec->val.c_nc.mh << 8 | valrec->val.c_nc.ml )
 
+
 #ifdef __cplusplus
 }
 #endif
